#!/bin/ksh
# IBM_PROLOG_BEGIN_TAG 
# This is an automatically generated prolog. 
#  
#  
#  
# Licensed Materials - Property of IBM 
#  
# (C) COPYRIGHT International Business Machines Corp. 2007,2010 
# All Rights Reserved 
#  
# US Government Users Restricted Rights - Use, duplication or 
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp. 
#  
# IBM_PROLOG_END_TAG 
##############################################################
#
# was applicationServer automation control script
#
# Input:
#       $1      action (<start|stop|status>)
#       $2      na_home, the nodeagent's home directory
#               USER_INSTALL_ROOT
#       $3      as_tcpp, the applicationServer's SOAP_CONNECTOR_ADDRESS
#       $4      server_name, name of the applicationServer
#
#
# History:
#
#   7.04.2005  initial version                             ms
#  15.12.2005  1. additional logger statements		     as
#		   2. status) do not report Online as long as
#		   the Launcher is still running
#
##############################################################
#
# init section
#
UNKNOWN=0
ONLINE=1
OFFLINE=2

GREP=/bin/grep
PS=/bin/ps
SU=/bin/su
KILL=/bin/kill
NETSTAT=/bin/netstat

if [ -a /etc/SuSE-release ]
then
        CUT=/usr/bin/cut
        LOGGER=/bin/logger
else
        CUT=/bin/cut
        LOGGER=/usr/bin/logger
fi

Action=${1:-status}
NA_HOME=$2
AS_TCPP=$3
SERVER_NAME=$4
AS_USER=${5:-root}

OS=$(uname -s)

# set number of open files to 9999 on AIX (nproc limit)
if [ "$OS" = "AIX" ]; then
   ulimit -S -n 9999
else
   ulimit -n 8000
fi

export PATH=$PATH:/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin:${NA_HOME}/bin

function is_running
{
    as_pid=$1
    ${PS} -p ${as_pid} -o "pid,args" | grep -q -E "${SERVER_NAME}"
    [ $? == 0 ] && return 1 || return 0
}

case ${Action} in
        start)
                ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} starting..."
                if [ "$OS" = "Linux" ]; then
                   ${SU} - ${AS_USER} -c "${NA_HOME}/bin/startServer.sh ${SERVER_NAME} -timeout 300"
                else
                   ${SU} - ${AS_USER} ${NA_HOME}/bin/startServer.sh ${SERVER_NAME} -quiet
                fi
                RC=$?
                ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} start rc: ${RC}"
                ;;
        stop)
                ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} stopping..."
                if [ "$OS" = "Linux" ]; then
                   ${SU} - ${AS_USER} -c "${NA_HOME}/bin/stopServer.sh ${SERVER_NAME} -timeout 180"
                else
                   ${SU} - ${AS_USER} ${NA_HOME}/bin/stopServer.sh ${SERVER_NAME} -quiet
                fi
                RC=$?
                if [ $RC -eq 0 ]; then
                  ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} stop rc: ${RC}"
                elif [ $RC -eq 246 ]; then
                  ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} stop rc: ${RC} (applicationServer did not run)."
                  RC=0
                else
                  ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} stop rc: ${RC}"
                  AS_pid=`${CUT} -f1 ${NA_HOME}/logs/${SERVER_NAME}/${SERVER_NAME}.pid`
                  ${KILL} -9 ${AS_pid} > /dev/null 2>&1
                  RC=$?
                  if [ $RC -eq 0 ]; then
                    ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} (pid ${AS_pid}) killed."
                  else
                    ${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} (pid ${AS_pid}) kill rc: ${RC}." 
                  fi
                fi
		
		if [[ $SA_RESET == 1 ]]; then # this is already the second STOP request 
		    AS_pid=`${CUT} -f1 ${NA_HOME}/logs/${SERVER_NAME}/${SERVER_NAME}.pid`
		    is_running $AS_pid
		    if [ $? == 1 ]; then # even after 2nd STOP invocation, it is still running 
			${LOGGER} -i -p info -t $0 "SA_RESET request, going to kill ApplicationServer ${SERVER_NAME} (pid ${AS_pid})."
			${KILL} -9 ${AS_pid} > /dev/null 2>&1
			${LOGGER} -i -p info -t $0 "ApplicationServer ${SERVER_NAME} (pid ${AS_pid}) killed."
		    fi
                    RC=0
		fi 
                ;;
        status)
                # do not report online while WsServerLauncher is running
                if [ "$OS" = "Linux" ]; then
                   AS_START=`${PS} -ef --cols 4096 | ${GREP} WsServerLauncher | ${GREP} ${SERVER_NAME}`
                else
                   AS_START=`${PS} -ef | ${GREP} WsServerLauncher | ${GREP} ${SERVER_NAME}`
                fi
                if [ "${AS_START}" != "" ];
                then
                  RC=$OFFLINE
                else
                  if [ "$OS" = "Linux" ]; then
                     AS_UP=`${NETSTAT} -lnt | ${GREP} :${AS_TCPP}`
                  else
                     AS_UP=`${NETSTAT} -an | ${GREP} LISTEN | ${GREP} tcp| ${GREP} .${AS_TCPP}`
                  fi
                  if [ "${AS_UP}" != "" ];
                  then
                    RC=$ONLINE
                  else
                    RC=$OFFLINE
                  fi
                fi
                ;;
        *)
                ${LOGGER} -i -p info -t $0 "Error: Incorrect parameter >${Action}<"
                RC=${UNKNOWN}
                ;;
esac

exit ${RC}
